@@ -244,7 +244,7 @@ void BoardWidget::updateSpriteMap()
                         thissprite->moveTo(sx, sy);
                     }
 
-                    if (thissprite) {
+                    if (thissprite && !gamePaused) {
                         thissprite->show();
                     }
                 }
@@ -304,7 +304,7 @@ void BoardWidget::updateSpriteMap()
                         thissprite->moveTo(sx, sy);
                     }
 
-                    if (thissprite) {
+                    if (thissprite && !gamePaused) {
                         thissprite->show();
                     }
                 }
@@ -361,7 +361,7 @@ void BoardWidget::updateSpriteMap()
                         thissprite->moveTo(sx, sy);
                     }
 
-                    if (thissprite) {
+                    if (thissprite && !gamePaused) {
                         thissprite->show();
                     }
                 }
@@ -412,7 +412,7 @@ void BoardWidget::updateSpriteMap()
                         thissprite->moveTo(sx, sy);
                     }
 
-                    if (thissprite) {
+                    if (thissprite && !gamePaused) {
                         thissprite->show();
                     }
                 }
@@ -448,7 +448,11 @@ void BoardWidget::updateSpriteMap()
 void BoardWidget::pause()
 {
     gamePaused = !gamePaused;
-    drawBoard(!gamePaused);
+    QListIterator<KGameCanvasItem*> i(m_items);
+    while (i.hasNext())
+    {
+        i.next()->setVisible(!gamePaused);
+    }
 }
 
 void BoardWidget::gameLoaded()
@@ -789,13 +793,9 @@ void BoardWidget::hilightTile(POSITION& Pos, bool on, bool doRepaint)
     }
 }
 
-void BoardWidget::drawBoard(bool showTiles)
+void BoardWidget::drawBoard(bool createTiles)
 {
-    if (gamePaused) {
-        showTiles = false;
-    }
-
-    if (showTiles) {
+    if (createTiles) {
         populateSpriteMap();
         drawTileNumber();
     } else {
